@@ -75,7 +75,7 @@
 
     @testset "triangular" begin
         @testset "copytri!" begin
-            @testset for eltya in (Float32, Float64, ComplexF32, ComplexF64), uplo in ('U', 'L'), conjugate in (true, false)
+            @testset for eltya in (Float32, Float64, ComplexF32, ComplexF64), uplo in ('U', 'L'), conjugate in (true, false), diag in (true, false)
                 if !(eltya in eltypes)
                     continue
                 end
@@ -83,7 +83,7 @@
                 areal = randn(n,n)/2
                 aimg  = randn(n,n)/2
                 a = convert(Matrix{eltya}, eltya <: Complex ? complex.(areal, aimg) : areal)
-                @test compare(x -> LinearAlgebra.copytri!(x, uplo, conjugate), AT, a)
+                @test compare(x -> LinearAlgebra.copytri!(x, uplo, conjugate, diag), AT, a)
             end
         end
 
